@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2015 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -276,6 +276,41 @@ CSFML_GRAPHICS_API void sfText_setFont(sfText* text, const sfFont* font);
 ////////////////////////////////////////////////////////////
 CSFML_GRAPHICS_API void sfText_setCharacterSize(sfText* text, unsigned int size);
 
+    ////////////////////////////////////////////////////////////
+/// \brief Set the line spacing factor
+///
+/// The default spacing between lines is defined by the font.
+/// This method enables you to set a factor for the spacing
+/// between lines. By default the line spacing factor is 1.
+///
+/// \param text Text object
+/// \param spacingFactor New line spacing factor
+///
+/// \see sfText_getLineSpacing
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API void sfText_setLineSpacing(sfText* text, float spacingFactor);
+
+////////////////////////////////////////////////////////////
+/// \brief Set the letter spacing factor
+///
+/// The default spacing between letters is defined by the font.
+/// This factor doesn't directly apply to the existing
+/// spacing between each character, it rather adds a fixed
+/// space between them which is calculated from the font
+/// metrics and the character size.
+/// Note that factors below 1 (including negative numbers) bring
+/// characters closer to each other.
+/// By default the letter spacing factor is 1.
+///
+/// \param text Text object
+/// \param spacingFactor New letter spacing factor
+///
+/// \see sfText_getLetterSpacing
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API void sfText_setLetterSpacing(sfText* text, float spacingFactor);
+
 ////////////////////////////////////////////////////////////
 /// \brief Set the style of a text
 ///
@@ -290,16 +325,60 @@ CSFML_GRAPHICS_API void sfText_setCharacterSize(sfText* text, unsigned int size)
 CSFML_GRAPHICS_API void sfText_setStyle(sfText* text, sfUint32 style);
 
 ////////////////////////////////////////////////////////////
-/// \brief Set the global color of a text
+/// \brief Set the fill color of a text
 ///
-/// By default, the text's color is opaque white.
+/// By default, the text's fill color is opaque white.
+/// Setting the fill color to a transparent color with an outline
+/// will cause the outline to be displayed in the fill area of the text.
 ///
 /// \param text  Text object
-/// \param color New color of the text
+/// \param color New fill color of the text
+///
+/// \deprecated This function is deprecated and may be removed in future releases.
+/// Use sfText_setFillColor instead.
 ///
 ////////////////////////////////////////////////////////////
 CSFML_GRAPHICS_API void sfText_setColor(sfText* text, sfColor color);
 
+////////////////////////////////////////////////////////////
+/// \brief Set the fill color of a text
+///
+/// By default, the text's fill color is opaque white.
+/// Setting the fill color to a transparent color with an outline
+/// will cause the outline to be displayed in the fill area of the text.
+///
+/// \param text  Text object
+/// \param color New fill color of the text
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API void sfText_setFillColor(sfText* text, sfColor color);
+
+////////////////////////////////////////////////////////////
+/// \brief Set the outline color of the text
+///
+/// By default, the text's outline color is opaque black.
+///
+/// \param text  Text object
+/// \param color New outline color of the text
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API void sfText_setOutlineColor(sfText* text, sfColor color);
+
+////////////////////////////////////////////////////////////
+/// \brief Set the thickness of the text's outline
+///
+/// By default, the outline thickness is 0.
+///
+/// Be aware that using a negative value for the outline
+/// thickness will cause distorted rendering.
+///
+/// \param thickness New outline thickness, in pixels
+///
+/// \see getOutlineThickness
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API void sfText_setOutlineThickness(sfText* text, float thickness);
+
 ////////////////////////////////////////////////////////////
 /// \brief Get the string of a text (returns an ANSI string)
 ///
@@ -344,6 +423,30 @@ CSFML_GRAPHICS_API const sfFont* sfText_getFont(const sfText* text);
 ////////////////////////////////////////////////////////////
 CSFML_GRAPHICS_API unsigned int sfText_getCharacterSize(const sfText* text);
 
+////////////////////////////////////////////////////////////
+/// \brief Get the size of the letter spacing factor
+///
+/// \param text Text object
+///
+/// \return Size of the letter spacing factor
+///
+/// \see sfText_setLetterSpacing
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API float sfText_getLetterSpacing(const sfText* text);
+
+////////////////////////////////////////////////////////////
+/// \brief Get the size of the line spacing factor
+///
+/// \param text Text object
+///
+/// \return Size of the line spacing factor
+///
+/// \see sfText_setLineSpacing
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API float sfText_getLineSpacing(const sfText* text);
+
 ////////////////////////////////////////////////////////////
 /// \brief Get the style of a text
 ///
@@ -355,15 +458,48 @@ CSFML_GRAPHICS_API unsigned int sfText_getCharacterSize(const sfText* text);
 CSFML_GRAPHICS_API sfUint32 sfText_getStyle(const sfText* text);
 
 ////////////////////////////////////////////////////////////
-/// \brief Get the global color of a text
+/// \brief Get the fill color of a text
 ///
 /// \param text Text object
 ///
-/// \return Global color of the text
+/// \return Fill color of the text
+///
+/// \deprecated This function is deprecated and may be removed in future releases.
+/// Use sfText_getFillColor instead.
 ///
 ////////////////////////////////////////////////////////////
 CSFML_GRAPHICS_API sfColor sfText_getColor(const sfText* text);
 
+////////////////////////////////////////////////////////////
+/// \brief Get the fill color of a text
+///
+/// \param text Text object
+///
+/// \return Fill color of the text
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API sfColor sfText_getFillColor(const sfText* text);
+
+////////////////////////////////////////////////////////////
+/// \brief Get the outline color of a text
+///
+/// \param text Text object
+///
+/// \return Outline color of the text
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API sfColor sfText_getOutlineColor(const sfText* text);
+
+////////////////////////////////////////////////////////////
+/// \brief Get the outline thickness of a text
+///
+/// \param text Text object
+///
+/// \return Outline thickness of a text, in pixels
+///
+////////////////////////////////////////////////////////////
+CSFML_GRAPHICS_API float sfText_getOutlineThickness(const sfText* text);
+
 ////////////////////////////////////////////////////////////
 /// \brief Return the position of the \a index-th character in a text
 ///
